# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/data/pointcloud.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto


@dataclass
class PointCloud(betterproto.Message):
    cartesian: bytes = betterproto.bytes_field(1)
    intensity: bytes = betterproto.bytes_field(2)
    ambient: bytes = betterproto.bytes_field(3)
    velocity: bytes = betterproto.bytes_field(4)
    reflectivity: bytes = betterproto.bytes_field(5)
    timestamp_offset: bytes = betterproto.bytes_field(6)
    channel_id: bytes = betterproto.bytes_field(7)
