# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/common/calibration.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto


@dataclass
class SensorCalibration(betterproto.Message):
    sensor_name: str = betterproto.string_field(1)
    extrinsic: List[float] = betterproto.float_field(2)
    vertical_fov: float = betterproto.float_field(3)
    horizontal_fov: float = betterproto.float_field(4)
    vertical_scanlines: int = betterproto.uint32_field(5)
    horizontal_scanlines: int = betterproto.uint32_field(6)
    horizontal_angle_spacing: float = betterproto.float_field(7)
    beam_altitude_angles: List[float] = betterproto.float_field(8)
    beam_azimuth_angles: List[float] = betterproto.float_field(9)
    frame_mode: str = betterproto.string_field(10)
    scan_pattern: str = betterproto.string_field(11)
