# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/frame.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto

from . import sensors


@dataclass
class Frame(betterproto.Message):
    """Frame fasst nur noch mehrere Sensor‐Scans zusammen."""

    frame_timestamp_ns: int = betterproto.uint64_field(1)
    lidars: List[sensors.LidarScan] = betterproto.message_field(2)
